summaryrefslogtreecommitdiffstats
path: root/smb4k/dialogs/smb4kprintdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/dialogs/smb4kprintdialog.h')
-rw-r--r--smb4k/dialogs/smb4kprintdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/smb4k/dialogs/smb4kprintdialog.h b/smb4k/dialogs/smb4kprintdialog.h
index bd2294c..af152ca 100644
--- a/smb4k/dialogs/smb4kprintdialog.h
+++ b/smb4k/dialogs/smb4kprintdialog.h
@@ -59,11 +59,11 @@ class Smb4KPrintDialog : public KDialogBase
*
* @param item The Smb4KShareItem of the printer.
*
* @param tqparent The tqparent widget of this dialog.
*
* @param name The name of this dialog.
*/
- Smb4KPrintDialog( Smb4KShareItem *item, TQWidget *tqparent = 0, const char *name = 0 );
+ Smb4KPrintDialog( Smb4KShareItem *item, TQWidget *parent = 0, const char *name = 0 );
/**
* The destructor
*/
@@ -59,11 +59,11 @@ class Smb4KPrintDialog : public KDialogBase
* @param item The Smb4KShareItem of the printer.
*
- * @param tqparent The tqparent widget of this dialog.
+ * @param parent The parent widget of this dialog.
*
* @param name The name of this dialog.